@@ -2,8 +2,10 @@ from pathlib import Path
 from cleo import Command, Application
 
 from coronacheck_tools.certificate_versions.v2 import v2_asn1_specs
-from coronacheck_tools.clitools import parse_input, write_output,  convert, VALID_FORMATS
-from coronacheck_tools.verification.verifier import validate_raw
+from coronacheck_tools.clitools import deep_get, parse_input, write_output,  convert, VALID_FORMATS
+from coronacheck_tools.verification.verifier import validate_raw, cconfig, readconfig as verifier_readconfig
+
+import json
 
 import pkg_resources  # part of setuptools
 
@@ -113,6 +115,7 @@ class VerifyCommand(Command):
     verify
         {input-format : Input format. QR, RAW, ASN1, JSON.}
         {input : Input file.}
+        {--e|ehc : Allow verification of European Health Certificates}
     """
 
     def handle(self):
@@ -134,12 +137,16 @@ class VerifyCommand(Command):
         input_data = parse_input(input_format, input_path)
         data = convert(input_format, input_data, "RAW")
 
+        if not data or len(data) == 0:
+            self.line(f"<error>No QR code detected!</error>")
+            return
+
         if isinstance(data, list):
             # if we have multiple QR codes only verify the first one
             data = data[0]
 
         # Allow international EHC qr codes?
-        allow_international = False
+        allow_international = True if self.option('ehc') else False
         result = validate_raw(data, allow_international=allow_international)
 
         if result[0]:
@@ -148,12 +155,46 @@ class VerifyCommand(Command):
             self.line(f"<error>Code is invalid</error> {result[1]}")
 
 
+class ClearConfigCommand(Command):
+    """
+    Remove the validators config files. Normally you should not need this command.
+
+    clean
+    """
+
+    def handle(self):
+        cconfig()
+        self.line('Config removed')
+
+class ListConfigCommand(Command):
+    """
+    List the (mobilecore) config.
+
+    config
+        {key? : Only show the config starting at <key>}
+    """
+
+    def handle(self):
+        verifier_config = verifier_readconfig()
+
+        config = {'verifier': verifier_config}
+
+        key = self.argument('key')
+        if key:
+            config = deep_get(config, key)
+
+        print(json.dumps(config, indent=2, sort_keys=True))
+
+
+
 def main():
     application = Application(name="coronacheck-tools", version=pkg_resources.require("coronacheck-tools")[0].version)
     application.add(DumpCommand())
     application.add(ConvertCommand())
     application.add(VerifyCommand())
     application.add(Asn1SpecCommand())
+    application.add(ClearConfigCommand())
+    application.add(ListConfigCommand())
 
     print(AFFILIATE_WARNING)
 
