@@ -1,3 +1,3 @@
-from coronacheck_tools.clitools.iotool import parse_input, write_output   # noqa: F401
+from coronacheck_tools.clitools.iotool import parse_input, write_output, deep_get   # noqa: F401
 from coronacheck_tools.clitools.convert import convert   # noqa: F401
 from coronacheck_tools.clitools.definitions import FORMAT_MAPPINGS, VALID_FORMATS   # noqa: F401
